OC.L10N.register(
    "calendar",
    {
    "Hello," : "שלום,",
    "Open »%s«" : "פתיחת „%s”",
    "Cheers!" : "ברכותינו!",
    "Calendar" : "יומן",
    "A Calendar app for Nextcloud" : "יישומון לוח שנה ל־Nextcloud",
    "Today" : "היום",
    "Day" : "יום",
    "Week" : "שבוע",
    "Month" : "חודש",
    "Copy private link" : "העתקת קישור פרטי",
    "Download" : "הורדה",
    "Delete" : "מחיקה",
    "Calendar link copied to clipboard." : "הקישור ללוח השנה הועתק ללוח הגזירים.",
    "Calendar link could not be copied to clipboard." : "לא ניתן להעתיק את הקישור ללוח השנה אל לוח הגזירים.",
    "Share link" : "שיתוף קישור",
    "Delete share link" : "מחיקת קישור שיתוף",
    "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
    "No users or groups" : "אין משתמשים או קבוצות",
    "can edit" : "ניתן לערוך",
    "New calendar" : "לוח שנה חדש",
    "Filename" : "שם קובץ",
    "Cancel" : "ביטול",
    "Automatic" : "אוטומטי",
    "Show week numbers" : "הצגת מספרי שבועות",
    "Settings & import" : "הגדרות וייבוא",
    "Email" : "דוא״ל",
    "Busy" : "עסוק",
    "Unknown" : "לא ידוע",
    "All day" : "כל היום",
    "never" : "לעולם לא",
    "after" : "לאחר",
    "Repeat" : "חזרה",
    "Monday" : "יום שני",
    "Summary" : "תקציר",
    "More" : "יותר",
    "Save" : "שמור",
    "Update" : "עדכון",
    "Select Date" : "בחירת תאריך",
    "Personal" : "אישי",
    "Details" : "פרטים",
    "Attendees" : "משתתפים",
    "Reminders" : "תזכורות",
    "Activity" : "פעילות",
    "Close" : "סגירה",
    "Anniversary" : "יום השנה",
    "Week {number} of {year}" : "שבוע {number} ב־{year}",
    "Daily" : "יומי",
    "Weekly" : "שבועי",
    "Untitled event" : "אירוע ללא כותרת",
    "When shared show full event" : "כאשר משותף מציג אירוע מלא",
    "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
    "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
    "Location" : "מיקום",
    "Description" : "תיאור",
    "Status" : "מצב",
    "Confirmed" : "מאושר",
    "Tentative" : "טנטטיבית",
    "Cancelled" : "בוטל",
    "Categories" : "קטגוריות",
    "Add this as a new category" : "הוספת הקטגוריה הזאת כחדשה",
    "Presentation" : "מצגת",
    "Cinema" : "בית קולנוע",
    "Office" : "משרד",
    "Mail" : "דואר",
    "Play" : "נגן",
    "Dentist" : "רופא/ת שיניים",
    "Global" : "גלובלי"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
